@@ -11,14 +11,34 @@
 # Arezqui Belaid <info@star2billing.com>
 #
 from django import template
-from django.utils import simplejson
 from django.utils.safestring import mark_safe
 from django.utils.datastructures import SortedDict
 import copy
+import json
 
 register = template.Library()
 
 
+def word_capital(text):
+    """
+    Capitalizes the first character of each word, it converts a string into
+    titlecase by making words start with an uppercase character and keep the
+    remaining characters.
+    """
+    if text and len(text) > 0:
+        return ' '.join([s[0].upper() + s[1:] for s in text.split(' ') if len(s) > 0])
+    else:
+        return text
+
+
+@register.filter(name='wordcap')
+def wordcap(value):
+    """
+    Capitalizes the first character of each words.
+    """
+    return word_capital(value)
+
+
 @register.filter(name='mul')
 def mul(value, arg):
     """Multiplication
@@ -156,7 +176,7 @@ def month_name(value, arg):
 
 @register.filter(name='to_json')
 def to_json(value):
-    return mark_safe(simplejson.dumps(value))
+    return mark_safe(json.dumps(value))
 
 
 @register.inclusion_tag('sort_link_frag.html', takes_context=True)
